@@ -25,7 +25,7 @@
 #include <stdio.h>
 #include <assert.h>
 #include <unistd.h>
-#include <sys/errno.h>
+#include <errno.h>
 #include <stdbool.h>
 #if HAVE_STRING_H
 #  include <string.h>
