@@ -68,7 +68,7 @@
 #include <assert.h>
 #include "export.h"
 #if HAVE_LIBCURL && !HAVE_FOPENCOOKIE
-# include "fopencookie.e"	/* Use our own fopencookie() */
+# include "fopencookie.h"	/* Use our own fopencookie() */
 #endif
 #include "dict.e"
 #include "heap.e"
@@ -475,7 +475,7 @@ EXPORT FILE *fopenurl(const conststring path, const conststring mode,
 #if HAVE_FCNTL_H
 #  include <fcntl.h>
 #endif
-#include <sys/errno.h>
+#include <errno.h>
 #if HAVE_SYS_SOCKET_H
 #  include <sys/socket.h>
 #endif
